@@ -10,15 +10,18 @@ from friktionutils.metrics import (
     annualized_return,
     cumulative_return,
     max_drawdown,
-    annualized_volatility,å
+    annualized_volatility,
     value_at_risk,
     expected_shortfall,
     tear_sheet,
 )
+from friktionutils.options import random_walk
 
 df = pd.DataFrame()
 df.index = pd.date_range(start="1/1/2020", periods=700, freq="D")
-df["returns"] = (np.power(np.e, np.random.lognormal(700)) - 1) * 0.01
+df["returns"] = random_walk(1, 700, 0, 100)
+df["returns"] = df.returns - 1
+print(df)
 
 
 @pytest.mark.parametrize(
